@@ -4,7 +4,6 @@ import typing
 
 from saq.utils import now, seconds, uuid1, exponential_backoff
 
-ID_PREFIX = "saq:job:"
 ABORT_ID_PREFIX = "saq:abort:"
 
 
@@ -132,11 +131,11 @@ class Job:
 
     @property
     def id(self):
-        return self.id_from_key(self.key)
+        return self.queue.job_id(self.key)
 
     @classmethod
-    def id_from_key(cls, job_key):
-        return f"{ID_PREFIX}{job_key}"
+    def key_from_id(cls, job_id):
+        return job_id.split(":")[-1]
 
     @property
     def abort_id(self):
@@ -239,7 +238,7 @@ class Job:
         until_complete: None or Numeric seconds. if None (default), don't wait,
             else wait seconds until the job is complete or the interval has been reached. 0 means wait forever
         """
-        job = await self.queue.job(self.id)
+        job = await self.queue.job(self.key)
 
         if not job:
             raise RuntimeError(f"{self} doesn't exist")
@@ -252,7 +251,7 @@ class Job:
                 if status in TERMINAL_STATUSES:
                     return True
 
-            await self.queue.listen([self.id], callback, until_complete)
+            await self.queue.listen([self.key], callback, until_complete)
             await self.refresh()
 
     def replace(self, job):
